import {v4 as uuid} from 'uuid'

import {hasUserConsents} from '@s-ui/consents'
import {PDE} from '@s-ui/pde'
import OptimizelyAdapter from '@s-ui/pde/lib/adapters/optimizely'

function readCookie(key, cookies) {
  const re = new RegExp(key + '=([^;]+)')
  const value = re.exec(cookies)
  return value !== null ? value[1] : null
}

const NODE_ENV = process.env.JOBS_ENV || process.env.NODE_ENV || ''
const PORTAL = process.env.PORTAL || 'net'

const env = (() => {
  switch (NODE_ENV) {
    case 'preproduction':
      return 'qaaws'
    case 'sbx':
      return 'sbx'
    default:
      return ''
  }
})()

const REQUIRED_CONSENTS = [1, 6, 8, 10]

let optimizelyAdapter

// Gets rid off the surrounding %22 that segment adds to the id.
// This happened with Segment SDK v1 and isn't removed as users might
// still be using the id generated by this older version.
const trim = id => {
  return decodeURIComponent(id).replace(/"/g, '')
}

const getSegmentIds = ({cookies}) => {
  const anonymousId = trim(readCookie('ajs_anonymous_id', cookies))
  return {
    anonymousId: anonymousId ?? uuid()
  }
}

export const getPDE = async ({cookies = window.document.cookie} = {}) => {
  await optimizelyAdapter.onReady()

  return new PDE({
    adapter: optimizelyAdapter,
    hasUserConsents: hasUserConsents({
      requiredConsents: REQUIRED_CONSENTS,
      cookies
    })
  })
}

export const initPDE = ({cookies = window.document.cookie} = {}) => {
  const [, environment, portal] = window.location.host.match(
    /infojobs(\w*)\.(\w*)/
  ) || ['', env, PORTAL]

  const optimizely = OptimizelyAdapter.createOptimizelyInstance({
    sdkKey:
      environment === '' ? 'QLDtpXvqkL57HTLnvpje2' : 'SMoRXD8Tv14sbH8o5tkYZ'
  })

  const {anonymousId} = getSegmentIds({cookies})

  optimizelyAdapter = new OptimizelyAdapter({
    optimizely,
    userId: anonymousId,
    hasUserConsents: hasUserConsents({
      requiredConsents: REQUIRED_CONSENTS,
      cookies
    }),
    applicationAttributes: {
      site: portal === 'it' ? 'infojobs.it' : 'infojobs.net'
    }
  })
}
